@@ -1,4 +1,6 @@
 
+## @knitr include=FALSE
+library(knitr);render_html()
 
 
 ## @knitr 2d_data
